@@ -1,7 +1,7 @@
 # Copyright (c) 2010-2019 openpyxl
 
 """
-Package medata
+Package metadata
 """
 
 __author__ = "See AUTHORS"
@@ -9,4 +9,4 @@ __author_email__ = "charlie.clark@clark-consulting.eu"
 __license__ = "MIT"
 __maintainer_email__ = "openpyxl-users@googlegroups.com"
 __url__ = "https://openpyxl.readthedocs.io"
-__version__ = "3.0.1"
+__version__ = "3.0.3"
