@@ -23,6 +23,6 @@ def read_chart(chartspace):
     chart.backWall = cs.chart.backWall
     chart.pivotSource = cs.pivotSource
     chart.pivotFormats = cs.chart.pivotFmts
-    chart.idx_base = min(s.idx for s in chart.series)
+    chart.idx_base = min((s.idx for s in chart.series), default=0)
 
     return chart
