@@ -1,5 +1,4 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2019 openpyxl
 
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors import (
@@ -17,6 +16,7 @@ from openpyxl.descriptors import (
 from openpyxl.descriptors.excel import Coordinate, Percentage
 
 from openpyxl.descriptors.nested import (
+    NestedInteger,
     NestedSet,
     NestedNoneSet,
     EmptyTag,
@@ -80,19 +80,6 @@ class DashStopList(Serialisable):
         self.ds = ds
 
 
-class LineJoinMiterProperties(Serialisable):
-
-    tagname = "miter"
-    namespace = DRAWING_NS
-
-    lim = Integer(allow_none=True)
-
-    def __init__(self,
-                 lim=None,
-                ):
-        self.lim = lim
-
-
 class LineProperties(Serialisable):
 
     tagname = "ln"
@@ -118,14 +105,14 @@ class LineProperties(Serialisable):
 
     round = EmptyTag()
     bevel = EmptyTag()
-    miter = Typed(expected_type=LineJoinMiterProperties, allow_none=True)
+    miter = NestedInteger(allow_none=True, attribute="lim")
 
     headEnd = Typed(expected_type=LineEndProperties, allow_none=True)
     tailEnd = Typed(expected_type=LineEndProperties, allow_none=True)
     extLst = Typed(expected_type=OfficeArtExtensionList, allow_none=True)
 
     __elements__ = ('noFill', 'solidFill', 'gradFill', 'pattFill',
-                    'prstDash', 'custDash', 'round', 'bevel', 'mitre', 'headEnd', 'tailEnd')
+                    'prstDash', 'custDash', 'round', 'bevel', 'miter', 'headEnd', 'tailEnd')
 
     def __init__(self,
                  w=None,
@@ -140,7 +127,7 @@ class LineProperties(Serialisable):
                  custDash=None,
                  round=None,
                  bevel=None,
-                 mitre=None,
+                 miter=None,
                  headEnd=None,
                  tailEnd=None,
                  extLst=None,
@@ -159,6 +146,6 @@ class LineProperties(Serialisable):
         self.custDash = custDash
         self.round = round
         self.bevel = bevel
-        self.mitre = bevel
+        self.miter = miter
         self.headEnd = headEnd
         self.tailEnd = tailEnd
