@@ -1,9 +1,8 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2018 openpyxl
+# Copyright (c) 2010-2019 openpyxl
 
 import datetime
 
-from openpyxl.compat import safe_string, unicode
+from openpyxl.compat import safe_string
 from openpyxl.utils.datetime import (
     CALENDAR_WINDOWS_1900,
     to_ISO8601,
@@ -16,7 +15,7 @@ from openpyxl.descriptors import (
     )
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors.nested import NestedText
-from openpyxl.xml.functions import (Element, tostring)
+from openpyxl.xml.functions import (Element, QName, tostring)
 from openpyxl.xml.constants import (
     COREPROPS_NS,
     DCORE_NS,
@@ -46,7 +45,7 @@ class QualifiedDateTime(NestedDateTime):
 
     def to_tree(self, tagname=None, value=None, namespace=None):
         el = super(QualifiedDateTime, self).to_tree(tagname, value, namespace)
-        el.set("{%s}type" % XSI_NS, "dcterms:W3CDTF")
+        el.set("{%s}type" % XSI_NS, QName(DCTERMS_NS, "W3CDTF"))
         return el
 
 
@@ -58,27 +57,27 @@ class DocumentProperties(Serialisable):
     tagname = "coreProperties"
     namespace = COREPROPS_NS
 
-    category = NestedText(expected_type=unicode, allow_none=True)
-    contentStatus = NestedText(expected_type=unicode, allow_none=True)
-    keywords = NestedText(expected_type=unicode, allow_none=True)
-    lastModifiedBy = NestedText(expected_type=unicode, allow_none=True)
+    category = NestedText(expected_type=str, allow_none=True)
+    contentStatus = NestedText(expected_type=str, allow_none=True)
+    keywords = NestedText(expected_type=str, allow_none=True)
+    lastModifiedBy = NestedText(expected_type=str, allow_none=True)
     lastPrinted = NestedDateTime(allow_none=True)
-    revision = NestedText(expected_type=unicode, allow_none=True)
-    version = NestedText(expected_type=unicode, allow_none=True)
+    revision = NestedText(expected_type=str, allow_none=True)
+    version = NestedText(expected_type=str, allow_none=True)
     last_modified_by = Alias("lastModifiedBy")
 
     # Dublin Core Properties
-    subject = NestedText(expected_type=unicode, allow_none=True, namespace=DCORE_NS)
-    title = NestedText(expected_type=unicode, allow_none=True, namespace=DCORE_NS)
-    creator = NestedText(expected_type=unicode, allow_none=True, namespace=DCORE_NS)
-    description = NestedText(expected_type=unicode, allow_none=True, namespace=DCORE_NS)
-    identifier = NestedText(expected_type=unicode, allow_none=True, namespace=DCORE_NS)
-    language = NestedText(expected_type=unicode,allow_none=True, namespace=DCORE_NS)
-    # Dubline Core Terms
+    subject = NestedText(expected_type=str, allow_none=True, namespace=DCORE_NS)
+    title = NestedText(expected_type=str, allow_none=True, namespace=DCORE_NS)
+    creator = NestedText(expected_type=str, allow_none=True, namespace=DCORE_NS)
+    description = NestedText(expected_type=str, allow_none=True, namespace=DCORE_NS)
+    identifier = NestedText(expected_type=str, allow_none=True, namespace=DCORE_NS)
+    language = NestedText(expected_type=str, allow_none=True, namespace=DCORE_NS)
+    # Dublin Core Terms
     created = QualifiedDateTime(allow_none=True, namespace=DCTERMS_NS)
     modified = QualifiedDateTime(allow_none=True, namespace=DCTERMS_NS)
 
-    __elements__ = ("creator","title", "description", "subject","identifier",
+    __elements__ = ("creator", "title", "description", "subject","identifier",
                   "language", "created", "modified", "lastModifiedBy", "category",
                   "contentStatus", "version", "revision", "keywords", "lastPrinted",
                   )
